# Contributing

This project is intended to be open-source and contributions are very welcome!

Please contribute on the [github repo](https://github.com/noamteyssier/ggetrs)

If you are new to rust or open source in general but still want to contribute
please don't hesitate to reach out!
I would be more than happy to help guide you through building your first module.

All new additions must pass and follow current testing standards.

## Contribution Flow Chart

1. Open an issue describing what you would like to add as a feature/problem you'd
like to fix

2. Fork the repository / create a branch

3. Make the changes you'd like to the branch (Commit frequently and describe the changes in your commit messages)

4. Open a pull request to main `ggetrs` repo and request a review
